==> msal-0.2.0-sources.jar: com/microsoft/identity/client/IAccount.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.client;

import java.io.Serializable;

/**
 * Interface describing MSAL's externally-exposed Account representation.
 */
public interface IAccount extends Serializable {

    /**
     * Gets the {@link IAccountIdentifier} for this Account -- this value is authority-specific.
     *
     * @return The AccountIdentifier.
     */
    IAccountIdentifier getAccountIdentifier();

    /**
     * Gets the home {@link IAccountIdentifier} for this IAccount -- for IAccount types with tenant
     * association[s], this value will be unique. Meaning, it's value is the same
     * in the IAccount's home tenant and in any guest tenants to which it may be associated.
     *
     * @return
     */
    IAccountIdentifier getHomeAccountIdentifier();

    /**
     * Gets the username of this IAccount.
     *
     * @return The username to get.
     */
    String getUsername();

    /**
     * Gets the environment for this Account.
     *
     * @return The environment to get.
     */
    String getEnvironment();

}

==> msal-2.2.0-sources.jar: com/microsoft/identity/client/IAccount.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.client;

import androidx.annotation.NonNull;

import java.io.Serializable;

public interface IAccount extends Serializable, IClaimable {

    /**
     * Gets the id of the account.
     * <p>
     * For the Microsoft Identity Platform: the OID of the account in its home tenant.
     *
     * @return The id.
     */
    @NonNull
    String getId();

    @NonNull
    String getAuthority();
}
